@@ -2,6 +2,8 @@ mod content;
 pub use self::content::StyleContext;
 use crate::*;
 use serde::{Deserialize, Serialize};
+#[doc=include_str!("readme.md")]
+pub mod resolved;
 
 /// Resolve when style is not specific or missing.
 #[derive(Debug, Clone, Default, PartialEq, Serialize, Deserialize)]
@@ -25,14 +27,11 @@ impl StyleResolver {
         Self { theme, local: Default::default(), once: Default::default() }
     }
     /// Set the style of the given element.
-    pub fn get_local_style(&self) -> &StyleContext {
+    pub fn view_local_style(&self) -> &StyleContext {
         &self.local
     }
     /// Set the style of the given element.
-    pub fn set_local_style<T>(&mut self, style: T)
-    where
-        T: GraphicsStyle,
-    {
+    pub fn set_local_style(&mut self, style: &dyn GraphicsStyle) {
         style.draw_style(&mut self.local);
     }
 }
